@@ -24,17 +24,14 @@ def makefile(name, contents):
 
     ` makefile(name='example_fie', contents='hello world, this is a file' ) `
     """
-    with open(f"{name}", 'r') as f:
+    with open(f"{name}", 'w') as f:
         f.write(f"""{contents}""")
 
 
 
-contents="""
-
-
-
+contents_="""
 {
-envshell: {
+"envshell": {
 "EnvironShell_Access": true
 "EnvironShell_Password": "changeme"
 },
@@ -191,13 +188,11 @@ browse(F)
 
 def create_dependencies(envname):
     os.mkdir(f"{envname}")
-    makefile("settings.json", 'w', contents=contents)
+    makefile("settings.json", contents=contents_)
     os.mkdir(f'{envname}_panel')
-    makefile("host.py", 'w', contents=hostpy)
-    makefile("panel/base.html", contents=html)
+    makefile("host.py", contents=hostpy)
+    makefile("index.html", contents=html)
     makefile(browsepy)
-    os.mkdir('UploadConfigs')
-    makefile("UploadConfigs/note.txt", "the current folder is for")
 
 
 def browse(filename):
